@@ -1,4 +1,4 @@
-import SimpleSpider
+from SimpleSpider import SimpleSpider
 import argparse
 
 
@@ -17,31 +17,31 @@ def main():
     if(args.single=="True"):
             print(args.single)
             if(args.re!=None):
-                result=SinglePageGetByRegEx(Url=args.url,RegEx=args.re)
+                result=SimpleSpider.SinglePageGetByRegEx(Url=args.url,RegEx=args.re)
                 if(args.print=="True"):
                     print(result)
                 if (args.output != None):
-                    ExportFileToExcel(result, args.output)
+                    SimpleSpider.ExportFileToExcel(result, args.output)
 
             else:
-                result=SinglePageGetByXpath(Url=args.url,Xpath=args.xpath)
+                result=SimpleSpider.SinglePageGetByXpath(Url=args.url,Xpath=args.xpath)
                 if (args.print == "True"):
                     print(result)
 
                 if(args.output!=None):
-                    ExportFileToExcel(result,args.output)
+                    SimpleSpider.ExportFileToExcel(result,args.output)
     else:
         indexlist = str(args.index).split(",")
         if (args.re != None):
 
-            result = MulityPageGetByRegEx(Url=args.url, IndexList=indexlist, RegEx=args.re)
+            result = SimpleSpider.MulityPageGetByRegEx(Url=args.url, IndexList=indexlist, RegEx=args.re)
             if (args.print == "True"):
                 print(result)
             if (args.output != None):
-                ExportFileToExcel(result, args.output)
+                SimpleSpider.ExportFileToExcel(result, args.output)
         else:
-            result = MulityPageGetByXpath(Url=args.url, IndexList=indexlist, RegEx=args.re)
+            result = SimpleSpider.MulityPageGetByXpath(Url=args.url, IndexList=indexlist, RegEx=args.re)
             if (args.print == "True"):
                 print(result)
             if (args.output != None):
-                ExportFileToExcel(result, args.output)
\ No newline at end of file
+                SimpleSpider.ExportFileToExcel(result, args.output)
\ No newline at end of file
